﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using System.IO;

public enum GAMESTATE { WELCOME, SETTING, MAP, END }
public enum GAMELEVEL { EASY, MEDIUM, HARD }

public class Manager : MonoBehaviour {
    private GAMESTATE state;
    
    public WelcomeWnd welcomeWnd;
    public SettingWnd settingWnd;
    [HideInInspector]
    public Dictionary<string, City> cityMap;
    public static Manager instance;
    public GAMELEVEL level; //难度
    public GameObject cam;
    void Init()
    {
        print("Awake");
        //初始化读表数据
        AnalyzeMain(ReadCsv(Application.dataPath + "/Config/Main.csv"));
        state = GAMESTATE.WELCOME;
        instance = this;
    }
    void Awake()
    {
        Init();
    }
    void Update()
    {
        switch(state)
        {
            case GAMESTATE.WELCOME:
                OnBegin();
                break;
            case GAMESTATE.SETTING:
                OnSetting();
                break;
            case GAMESTATE.MAP:
                OnMap();
                break;
            case GAMESTATE.END:
                OnEnd();
                break;
        }
    }
    void OnBegin()
    {

    }
    void OnSetting()
    {

    }
    void OnMap()
    {

    }
    void OnEnd()
    {

    }
    void CloseWnd()
    {
        switch (state)
        {
            case GAMESTATE.WELCOME:
                welcomeWnd.gameObject.SetActive(false);
                break;
            case GAMESTATE.SETTING:
                settingWnd.gameObject.SetActive(false);
                break;
            case GAMESTATE.MAP:
                MapWnd.instance.mapWnd.gameObject.SetActive(false);
                OnMap();
                break;
            case GAMESTATE.END:
                EndWnd.instance.endWnd.gameObject.SetActive(false);
                break;
        }
    }
    public void OnReturnEnter()
    {
        CloseWnd();
        state = GAMESTATE.WELCOME;
        welcomeWnd.gameObject.SetActive(true);
    }

    public void SettingEnter()
    {
        if (state == GAMESTATE.SETTING)
            return;
        CloseWnd();
        state = GAMESTATE.SETTING;
        settingWnd.gameObject.SetActive(true);
    }
    public void MapEnter()
    {
        if (state == GAMESTATE.MAP)
            return;
        CloseWnd();
        cam.SetActive(false);
        state = GAMESTATE.MAP;
        PlayerController.instance.SetPlayerInfo();
        //MapWnd.instance.OpenAllCollider();
        MapWnd.instance.mapWnd.gameObject.SetActive(true);
    }
    public void EndEnter(bool victory)
    {
        if (state == GAMESTATE.END)
            return;
        CloseWnd();
        cam.SetActive(true);
        state = GAMESTATE.END;
        EndWnd.instance.Show(victory);
        EndWnd.instance.endWnd.gameObject.SetActive(true);
    }
    private List<string> ReadCsv(string filePath)
    {
        //string filePath = "C:\\Users\\user\\Desktop\\Main.csv";
        FileInfo fi = new FileInfo(filePath);
        if (!fi.Directory.Exists)
        {
            print("文件不存在");
            fi.Directory.Create();
        }
        List<string> csv = new List<string>();
        StreamReader sr = new StreamReader(filePath, System.Text.Encoding.UTF8);
        string str = sr.ReadLine();
        while (str != null)
        {
            str = sr.ReadLine();
            if (str[0] == ',')
            {
                break;
            }
            csv.Add(str);
        }
        return csv;
    }

    private void AnalyzeMain(List<string> csv)
    {
        if (csv == null || csv.Count <= 0)
            return;
        cityMap = new Dictionary<string, City>();
        string[] str, adjs, price;
        City city;
        for (int i = 0; i < csv.Count; ++i)
        {
            str = csv[i].Split(',');
            if(cityMap.ContainsKey(str[0]))
            {
                city = cityMap[str[0]];
                city.name = str[1];
            }
            else
            {
                city = new City(str[0], str[1]);
                cityMap.Add(str[0], city);
            }
            if (str[2] == "" || str[3] == "")
                continue;
            adjs = str[2].Split(':');
            price = str[3].Split(':');
            for(int j = 0; j < adjs.Length; ++j)
            {
                //添加正向邻接点
                if (cityMap[city.id].adjs.ContainsKey(adjs[j]))
                    continue;
                cityMap[city.id].adjs.Add(adjs[j], new Edge(adjs[j], int.Parse(price[j])));
                //添加反向邻接点
                if (!cityMap.ContainsKey(adjs[j]))
                {
                    cityMap.Add(adjs[j], new City(adjs[j], null));
                }
                if (cityMap[adjs[j]].adjs.ContainsKey(city.id))
                   continue;
                cityMap[adjs[j]].adjs.Add(city.id, new Edge(city.id, int.Parse(price[j])));
            }
            
        }
        
    }
}