﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerController : MonoBehaviour {
    public enum STATE { IDLE, MOVE };
    public STATE state;
    [HideInInspector]
    public Transform target;
    private UILabel moneyLabel;
    //private UISprite sprite;
    //private List<string> iconList;
    //private int iconIndex;
    //private float timer;
    //private Transform lastTarget;
    private Transform icon;

    public GameObject rolecam;
    public Transform player;
    public float speed;
    public float switchIdle;
    public string hometown; //家乡城市ID
    public string startPoint; //起点城市ID
    [HideInInspector]
    public static PlayerController instance;
    public float moneyFactor;
    public int money;
    [HideInInspector]
    public HashSet<string> path;
    private AudioSource audio;

    private void Awake()
    {
        state = STATE.IDLE;
        speed = 0.3f;
        switchIdle = 0.2f;
        moneyLabel = player.Find("Info/Money").GetComponent<UILabel>();
        audio = player.Find("Camera").GetComponent<AudioSource>();
        //money = 1000;
        //moneyLabel.text = string.Format("{0}元", money);
        //iconList = new List<string> { "Emoticon - Annoyed", "Emoticon - Frown" };
        //sprite = player.GetComponentInChildren<UISprite>();
        icon = player.Find("Icon");
        instance = this;
    }

    private void OnIdle()
    {
        //切换idle状态
    }

    private void OnMove()
    {
        if (Vector3.Distance(player.transform.position, target.position) < 0.001f)
        {
            audio.enabled = false;
            state = STATE.IDLE;
            //sprite.spriteName = iconList[0];
            path.Add(target.name);
            MapWnd.instance.RefreshCityInfo(target.name);
            if(IsDeadLine())
            {
                //死路，失败
                Manager.instance.EndEnter(false);
            }
            if(target.name.Equals(hometown))
            {
                //chenggo
                player.Find("Fireworks").gameObject.SetActive(true);
            }
            return;
        }
        //timer += Time.deltaTime;
        //if (timer > switchIdle)
        //{
        //    timer = 0.0f;
        //    iconIndex = (iconIndex + 1) % iconList.Count;
        //    sprite.spriteName = iconList[iconIndex];
        //}
        player.transform.position = Vector3.MoveTowards(player.transform.position, target.position, Time.deltaTime * speed);
        //if (int.Parse(target.name) == int.Parse(hometown))
        //{
        //    MapWnd.instance.mapWnd.transform.Find("Player").Find("Info").Find("BgSprite1").gameObject.SetActive(true);
        //}
        //关闭上一次的结点
        //lastTarget.GetComponent<BoxCollider>().enabled = false;
        //lastTarget.GetComponent<BoxCollider>().isTrigger = false;
        //lastTarget = target;
    }

    private void Update()
    {
        switch(state)
        {
            case STATE.IDLE:
                OnIdle();
                break;
            case STATE.MOVE:
                OnMove();
                break;
        }
        if (Input.GetKey(KeyCode.W))
        {
            rolecam.transform.localPosition += new Vector3(0,5,0);
        }
        if(Input.GetKey(KeyCode.S))
        {
            rolecam.transform.localPosition -= new Vector3(0,5,0);
        }
        if (Input.GetKey(KeyCode.A))
        {
            rolecam.transform.localPosition -= new Vector3(5,0,0);
        }
        if (Input.GetKey(KeyCode.D))
        {
            rolecam.transform.localPosition += new Vector3(5,0,0);
        }
    }

    public void Move(Transform tf)
    {
        if (state == STATE.MOVE)
            return;
        int price = Manager.instance.cityMap[target.name].adjs[tf.name].price;
        if (money < price)
        {
            //MapWnd.instance.mapWnd.transform.Find("Player").Find("Info").Find("BgSprite").gameObject.SetActive(true);
            Manager.instance.EndEnter(false);
            return;
        }
        money = money - price;
        moneyLabel.text = string.Format("{0}元", money);
        state = STATE.MOVE;
        target = tf;
        //timer = 0.0f;
        //iconIndex = 0;

        if(tf.position.x - player.position.x > 0)
        {
            icon.eulerAngles = new Vector3(0, 180, 0);
        }
        else
        {
            icon.eulerAngles = new Vector3(0, 0, 0);
        }

        audio.enabled = true;
    }

    public void SetPlayerInfo()
    {
        path = new HashSet<string>();
        startPoint = ComputeStartPoint();
        //hometown = id;
        Transform tf = MapWnd.instance.mapWnd.Find(string.Format("Map/{0}", startPoint));
        player.position = tf.position;
        target = tf;
        //lastTarget = target;
        path.Add(startPoint);
        MapWnd.instance.RefreshCityInfo(startPoint);
        money = ComputeMoney();
        moneyLabel.text = string.Format("{0}元", money);
    }

    private string ComputeStartPoint()
    {
        string[] candidates = new string[] { "1001", "1002", "1011", "1019", "1021", "1017", "1003", "1004" };
        string start = "";
        int maxDis = 0;
        foreach (string id in candidates)
        {
            int dis = GetCityDistance(id, hometown);
            if (dis > maxDis)
            {
                maxDis = dis;
                start = id;
            }
        }
        return start;
    }

    private int GetCityDistance(string a, string b)
    {
        int dis = 0;
        HashSet<string> visit = new HashSet<string>();
        Queue<string> queue = new Queue<string>();
        queue.Enqueue(a);
        while (queue.Count > 0)
        {
            string city = queue.Dequeue();
            if (visit.Contains(city))
                continue;
            visit.Add(city);
            foreach (KeyValuePair<string, Edge> pair in Manager.instance.cityMap[city].adjs)
            {
                if (pair.Key == b)
                {
                    return dis;
                }
                queue.Enqueue(pair.Key);
            }
            ++dis;
        }
        return dis;
    }

    private int ComputeMoney()
    {
        HashSet<string> visit = new HashSet<string>();
        int min = int.MaxValue, max = 0;
        GetCityDistancePrice(startPoint, hometown, ref visit, 0, ref min, ref max);
        return Mathf.CeilToInt(min * moneyFactor + max * (1 - moneyFactor));
    }

    private bool GetCityDistancePrice(string a, string b, ref HashSet<string> visit, int price, ref int min, ref int max)
    {
        visit.Add(a);
        if (a == b)
        {
            if (price < min)
            {
                min = price;
            }
            if (price > max)
            {
                max = price;
            }
            visit.Remove(a);
            return true;
        }
        bool ans = false;
        foreach (KeyValuePair<string, Edge> pair in Manager.instance.cityMap[a].adjs)
        {
            if (visit.Contains(pair.Key))
                continue;
            ans = GetCityDistancePrice(pair.Key, b, ref visit, price + pair.Value.price, ref min, ref max) || ans;
        }
        if (ans)
        {
            visit.Remove(a);
        }
        return ans;
    }

    private bool IsDeadLine()
    {
        bool hasOtherLine = false;
        foreach(KeyValuePair<string, Edge> pair in Manager.instance.cityMap[target.name].adjs)
        {
            if (!path.Contains(pair.Key))
            {
                hasOtherLine = true;
            }
        }
        return !hasOtherLine;
    }
}
